instrumenttools.Piccolo
=======================

.. inheritance-diagram:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo
   :private-bases:

.. autoclass:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.default_instrument_name

    Inherited from :py:class:`contexttools.InstrumentMark <abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark>`

.. autoattribute:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.default_short_instrument_name

    Inherited from :py:class:`contexttools.InstrumentMark <abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark>`

.. autoattribute:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.effective_context

    Inherited from :py:class:`contexttools.ContextMark <abjad.tools.contexttools.ContextMark.ContextMark.ContextMark>`

.. autoattribute:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.interval_of_transposition

    Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

.. autoattribute:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.is_primary_instrument

    Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

.. autoattribute:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.is_secondary_instrument

    Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

.. autoattribute:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.is_transposing

    Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

.. autoattribute:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.lilypond_format

    Inherited from :py:class:`contexttools.InstrumentMark <abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark>`

.. autoattribute:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.start_component

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. autoattribute:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. autoattribute:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.target_context

    Inherited from :py:class:`contexttools.ContextMark <abjad.tools.contexttools.ContextMark.ContextMark.ContextMark>`

.. autoattribute:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.traditional_pitch_range

    Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.all_clefs

    Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

.. autoattribute:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.instrument_name

    Inherited from :py:class:`contexttools.InstrumentMark <abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark>`

.. autoattribute:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.instrument_name_markup

    Inherited from :py:class:`contexttools.InstrumentMark <abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark>`

.. autoattribute:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.pitch_range

    Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

.. autoattribute:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.primary_clefs

    Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

.. autoattribute:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.short_instrument_name

    Inherited from :py:class:`contexttools.InstrumentMark <abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark>`

.. autoattribute:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.short_instrument_name_markup

    Inherited from :py:class:`contexttools.InstrumentMark <abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark>`

.. autoattribute:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.sounding_pitch_of_fingered_middle_c

    Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

Methods
-------

.. automethod:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.attach

    Inherited from :py:class:`contexttools.ContextMark <abjad.tools.contexttools.ContextMark.ContextMark.ContextMark>`

.. automethod:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.detach

    Inherited from :py:class:`contexttools.ContextMark <abjad.tools.contexttools.ContextMark.ContextMark.ContextMark>`

.. automethod:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.get_default_performer_name

    Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

.. automethod:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.get_performer_names

    Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

Special Methods
---------------

.. automethod:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.__call__

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.__delattr__

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.__eq__

    Inherited from :py:class:`contexttools.InstrumentMark <abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark>`

.. automethod:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.__hash__

    Inherited from :py:class:`contexttools.InstrumentMark <abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark>`

.. automethod:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.__ne__

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.__repr__

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`
